%bcond_without	python3

%define		module		maturin
%define		crates_ver	1.8.7

Summary:	Build and publish Rust crates as Python packages
Summary(pl.UTF-8):	Budowanie i publikowanie pak Rusta jako pakietów Pythonowych
Name:		maturin
Version:	1.8.7
Release:	1
License:	MIT or Apache v2.0
Group:		Applications
Source0:	https://github.com/PyO3/maturin/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	cdaa2fd0d6192a7e0950796310bb55df
# ./create-crates.sh
Source1:	%{name}-crates-%{crates_ver}.tar.xz
# Source1-md5:	dc9f09791c7d038bd6be38209675d399
Patch0:		x32.patch
URL:		https://github.com/PyO3/maturin
BuildRequires:	bzip2-devel
BuildRequires:	cargo
BuildRequires:	diffstat
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 2.044
BuildRequires:	rust >= 1.74
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
BuildRequires:	xz-devel
%if %{with python3}
BuildRequires:	python3-build
BuildRequires:	python3-installer
BuildRequires:	python3-modules >= 1:3.7
BuildRequires:	python3-setuptools
BuildRequires:	python3-setuptools_rust >= 1.11.0
%if "%{_ver_lt %{py3_ver} 3.11}" == "1"
BuildRequires:	python3-tomli >= 1.1.0
%endif
%endif
ExclusiveArch:	%{rust_arches}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Build and publish crates with pyo3, rust-cpython and cffi bindings as
well as rust binaries as Python packages.

%description -l pl.UTF-8
Budowanie i publikowanie pak przy użyciu wiązań pyo3, rust-cpython i
cffi, a także binariów Rusta jako pakietów Pythona.

%package -n python3-%{module}
Summary:	Maturin bindings for Python
Summary(pl.UTF-8):	Wiązania Maturina dla Pythona
Group:		Libraries/Python
Requires:	python3-modules >= 1:3.7
Requires:	%{name} = %{version}-%{release}

%description -n python3-%{module}
Maturin bindings for Python.

%description -n python3-%{module} -l pl.UTF-8
Wiązania Maturina dla Pythona.

%prep
%setup -q -a1

%{__mv} maturin-%{crates_ver}/* .
sed -i -e 's/@@VERSION@@/%{version}/' Cargo.lock

diffstat -l -p1 %{PATCH0} | xargs sha256sum > x32.patch.sha256
%patch -P0 -p1
cat x32.patch.sha256 | while read old_sum f; do
	new_sum=$(sha256sum $f | cut -f1 -d' ')
	test "$old_sum" != "$new_sum"
	%{__sed} -i -e "s/$old_sum/$new_sum/" vendor/ring/.cargo-checksum.json
done

# use our offline registry
export CARGO_HOME="$(pwd)/.cargo"

mkdir -p "$CARGO_HOME"
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'

[source.vendored-sources]
directory = '$PWD/vendor'
EOF

%build
export CARGO_HOME="$(pwd)/.cargo"

%cargo_build --frozen

%if %{with python3}
export MATURIN_SETUP_ARGS="%__cargo_common_opts --target %rust_target --target-dir %cargo_targetdir"
%py3_build_pyproject
%endif

%install
rm -rf $RPM_BUILD_ROOT
export CARGO_HOME="$(pwd)/.cargo"

%cargo_install --frozen --root $RPM_BUILD_ROOT%{_prefix} --path $(pwd)

%if %{with python3}
export MATURIN_SETUP_ARGS="%__cargo_common_opts --target %rust_target --target-dir %cargo_targetdir"
%{__rm} $RPM_BUILD_ROOT%{_bindir}/maturin
%py3_install_pyproject
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc Changelog.md README.md
%attr(755,root,root) %{_bindir}/maturin

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%{py3_sitedir}/%{module}
%{py3_sitedir}/%{module}-%{version}.dist-info
%endif
%changelog
* Wed Jun 25 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/maturin.git;a=log;h=master

* Sun Jun 22 2025 Jan Palus <atler@pld-linux.org> 20c4960
- up to 1.8.7

* Sun Jun 22 2025 Jan Palus <atler@pld-linux.org> aea4ca7
- drop create-crates.sh script in favor of rust-crates.sh

* Sun Jun 22 2025 Jan Palus <atler@pld-linux.org> 231a320
- rely on python macros passing correct rust flags

* Sun Jun 22 2025 Jan Palus <atler@pld-linux.org> 6bf3eeb
- BR: bzip2-devel xz-devel

* Mon May 26 2025 Jakub Bogusz <qboosh@pld-linux.org> c58ba69
- updated dependencies

* Mon May 26 2025 Jakub Bogusz <qboosh@pld-linux.org> e6ea69c
- pl

* Mon May 26 2025 Jakub Bogusz <qboosh@pld-linux.org> 7406a1f
- use plain build dir instead of %%builddir macro (which bumps rpm dependency to >= 1:4.19)

* Sun May 25 2025 Jan Rękorajski <baggins@pld-linux.org> b90f666
- rel 2, update vendored files checksums after patch

* Sun May 25 2025 Jan Rękorajski <baggins@pld-linux.org> 05d270d
- build fixes for x32

* Sun May 18 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> a6e5080
- Up to 1.8.6

* Sun Mar 16 2025 Jan Palus <atler@pld-linux.org> c6e4696
- setup cargo/rust flags for python module

* Sun Mar 16 2025 Jan Palus <atler@pld-linux.org> 0ff5785
- attempt to fix build on x32

* Sun Mar 16 2025 Jan Palus <atler@pld-linux.org> bdf5a0d
- no need to cleanup metadata anymore

* Mon Mar 03 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> 4baeda9
- Up to 1.8.2

* Mon Mar 03 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> 0eaf536
- Rel 3; add python module

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> 51328f0
- rebuild with separate debuginfo build-ids

* Wed Apr 14 2021 Jan Palus <atler@pld-linux.org> 531002c
- new

